@@ -24,9 +24,9 @@ power plant databases.
 
 from __future__ import absolute_import
 
-__version__ = "0.5.4"
-__author__ = "Fabian Hofmann, Jonas Hoersch, Fabian Gotzens"
-__copyright__ = "Copyright 2017-2020 Frankfurt Institute for Advanced Studies"
+__version__ = "0.5.6"
+__author__ = "Fabian Hofmann"
+__copyright__ = "Copyright 2017-2022 Technical University of Berlin"
 # The rough hierarchy of this package is
 # core, utils, heuristics, cleaning, matching, collection, data
 
@@ -37,5 +37,5 @@ __copyright__ = "Copyright 2017-2020 Frankfurt Institute for Advanced Studies"
 # convenience.
 from . import core, data, heuristics, plot, utils
 from .accessor import PowerPlantAccessor
-from .collection import matched_data as powerplants
+from .collection import powerplants
 from .core import get_config, package_config
