@@ -116,7 +116,11 @@ def BEYONDCOAL(raw=False, update=False, config=None):
 
 
 def OPSD(
-    raw=False, update=False, statusDE=None, config=None, **fill_geoposition_kwargs
+    raw=False,
+    update=False,
+    statusDE=None,
+    config=None,
+    **fill_geoposition_kwargs,
 ):
     """
     Importer for the OPSD (Open Power Systems Data) database.
@@ -207,7 +211,10 @@ def OPSD(
     return (
         pd.concat([opsd_EU, opsd_DE], ignore_index=True)
         .replace(
-            {"Country": {"UK": "GB", "[ \t]+|[ \t]+$.": ""}, "Capacity": {0.0: np.nan}},
+            {
+                "Country": {"UK": "GB", "[ \t]+|[ \t]+$.": ""},
+                "Capacity": {0.0: np.nan},
+            },
             regex=True,
         )
         .pipe(gather_specifications, config=config)
@@ -295,6 +302,7 @@ def GEO(raw=False, update=False, config=None):
     not_included_ppl = ppl.query("projectID not in @res.projectID")
     res = pd.concat([res, not_included_ppl]).pipe(set_column_name, "GEO")
     res = scale_to_net_capacities(res)
+    res = convert_to_short_name(res)
     res = set_column_name(res, "GEO")
     res = config_filter(res, config)
     res["projectID"] = "GEO-" + res.projectID.astype(str)
@@ -414,6 +422,17 @@ def JRC(raw=False, update=False, config=None):
         "storage_capacity_MWh": "StorageCapacity_MWh",
     }
 
+    def set_large_spanish_stores_to_reservoirs(df):
+        """
+        Set large Spanish stores which are larger than 50GWh to reservoirs.
+
+        These should will all assumed to be reservoirs.
+        Used to fix https://github.com/PyPSA/powerplantmatching/issues/72"
+        """
+        where = (df.Country == "Spain") & (df.StorageCapacity_MWh > 50e3)
+        technology = np.where(where, "Reservoir", df.Technology)
+        return df.assign(Technology=technology)
+
     df = (
         df.rename(columns=RENAME_COLUMNS)
         .assign(projectID=lambda df: "JRC-" + df.projectID.astype(str))
@@ -434,6 +453,7 @@ def JRC(raw=False, update=False, config=None):
         .drop(columns=["pypsa_id", "GEO"])
         .powerplant.convert_alpha2_to_country()
         .pipe(clean_name)
+        .pipe(set_large_spanish_stores_to_reservoirs)
         .pipe(set_column_name, "JRC")
         .pipe(config_filter, config)
     )
@@ -462,7 +482,8 @@ def IWPDCY(config=None):
     return (
         pd.read_csv(config["IWPDCY"]["fn"], encoding="utf-8", index_col="id")
         .assign(
-            File="IWPDCY.csv", projectID=lambda df: "IWPDCY-" + df.index.astype(str)
+            File="IWPDCY.csv",
+            projectID=lambda df: "IWPDCY-" + df.index.astype(str),
         )
         .dropna(subset=["Capacity"])
         .pipe(set_column_name, "IWPDCY")
@@ -517,7 +538,7 @@ def Capacity_stats(
         .rename(columns=str.title)
         .powerplant.convert_alpha2_to_country()
         .pipe(gather_fueltype_info, config=config, search_col=["Fueltype"])
-        .query("Fueltype in @fueltypes")
+        .query("Fueltype in @fueltypes and Fueltype != 'Other'")
         .pipe(set_column_name, source.title())
     )
     return df
@@ -566,10 +587,15 @@ def GPD(raw=False, update=False, config=None, filter_other_dbs=True):
     countries = config["target_countries"]
     return (
         df.rename(columns=lambda x: x.title())
-        .query("Country_Long in @countries &" " Source not in @other_dbs")
         .drop(columns="Country")
         .rename(columns=RENAME_COLS)
-        .pipe(gather_specifications, parse_columns=["Name", "Fueltype"], config=config)
+        .pipe(convert_to_short_name)
+        .query("Country in @countries &" " Source not in @other_dbs")
+        .pipe(
+            gather_specifications,
+            parse_columns=["Name", "Fueltype"],
+            config=config,
+        )
         .pipe(clean_name)
         .pipe(set_column_name, "GPD")
         .pipe(config_filter, config)
@@ -616,7 +642,7 @@ def WIKIPEDIA(raw=False, update=False, config=None):
             Set="PP",
             projectID=lambda df: "WIKIPEDIA-" + df.index.astype(str),
             # plants which are not yet built are set to 2027
-            DateIn=lambda df: df.DateIn.where(df.DateOut != 2051, 2027),
+            DateIn=lambda df: df.DateIn.where(~df.Status.str.contains("In Bau"), 2027),
         )
         .pipe(set_column_name, "WIKIPEDIA")
         .pipe(config_filter, config)
@@ -625,7 +651,11 @@ def WIKIPEDIA(raw=False, update=False, config=None):
 
 
 def ENTSOE(
-    raw=False, update=False, config=None, entsoe_token=None, **fill_geoposition_kwargs
+    raw=False,
+    update=False,
+    config=None,
+    entsoe_token=None,
+    **fill_geoposition_kwargs,
 ):
     """
     Importer for the list of installed generators provided by the ENTSO-E
@@ -648,7 +678,7 @@ def ENTSOE(
         defaults to powerplantmatching.config.get_config()
     entsoe_token: String
         Security token of the ENTSO-E Transparency platform
-    fill_geoposition_kwargs: 
+    fill_geoposition_kwargs:
         Keyword arguments passed to `fill_geoposition`.
 
     Note: For obtaining a security token refer to section 2 of the
@@ -913,7 +943,7 @@ def WEPP(raw=False, config=None):
         },
         inplace=True,
     )
-    wepp.loc[:, "DateRetrofit"] = wepp.DateIn
+    wepp["DateRetrofit"] = wepp.DateIn
     # Do country transformations and drop those which are not in defined scope
     c = {
         "ENGLAND & WALES": "UNITED KINGDOM",
@@ -988,7 +1018,11 @@ def WEPP(raw=False, config=None):
         wepp.Turbtype.str.contains("KAPLAN|BULB", case=False), "Technology"
     ] = "Run-Of-River"
     wepp.Technology = wepp.Technology.replace(
-        {"CONV/PS": "Pumped Storage", "CONV": "Reservoir", "PS": "Pumped Storage"}
+        {
+            "CONV/PS": "Pumped Storage",
+            "CONV": "Reservoir",
+            "PS": "Pumped Storage",
+        }
     )
     tech_st_pattern = [
         "ANTH",
@@ -1030,7 +1064,16 @@ def WEPP(raw=False, config=None):
         "IC/CP",
         "IC/GT",
     ]
-    ut_ocgt_pattern = ["GT", "GT/D", "GT/H", "GT/HY", "GT/IC", "GT/S", "GT/T", "GTC"]
+    ut_ocgt_pattern = [
+        "GT",
+        "GT/D",
+        "GT/H",
+        "GT/HY",
+        "GT/IC",
+        "GT/S",
+        "GT/T",
+        "GTC",
+    ]
     ut_st_pattern = ["ST", "ST/D"]
     ut_ic_pattern = ["IC", "IC/H"]
     wepp.loc[wepp.Utype.isin(ut_ccgt_pattern), "Technology"] = "CCGT"
@@ -1040,7 +1083,8 @@ def WEPP(raw=False, config=None):
     wepp.loc[wepp.Utype == "WTG", "Technology"] = "Onshore"
     wepp.loc[wepp.Utype == "WTG/O", "Technology"] = "Offshore"
     wepp.loc[
-        (wepp.Fueltype == "Solar") & (wepp.Utype.isin(ut_st_pattern)), "Technology"
+        (wepp.Fueltype == "Solar") & (wepp.Utype.isin(ut_st_pattern)),
+        "Technology",
     ] = "CSP"
     # Derive the SET column
     chp_pattern = [
@@ -1404,7 +1448,10 @@ def OPSD_VRE(raw=False, update=False, config=None):
                 "municipality": "Name",
             }
         )
-        .assign(DateIn=lambda df: df.commissioning_date.str[:4].astype(float), Set="PP")
+        .assign(
+            DateIn=lambda df: df.commissioning_date.str[:4].astype(float),
+            Set="PP",
+        )
         .powerplant.convert_alpha2_to_country()
         .pipe(set_column_name, "OPSD_VRE")
         .pipe(config_filter, config)
@@ -1413,7 +1460,7 @@ def OPSD_VRE(raw=False, update=False, config=None):
 
 def OPSD_VRE_country(country, raw=False, update=False, config=None):
     """
-    Get country specifig data from OPSD for renewables, if available.
+    Get country specific data from OPSD for renewables, if available.
     Available for DE, FR, PL, CH, DK, CZ and SE (last update: 09/2020).
 
     Parameters
@@ -1535,9 +1582,9 @@ def IRENASTAT(raw=False, update=False, config=None):
     return df
 
 
-def GEM_GGPT(raw=False, update=False, config=None):
+def GGPT(raw=False, update=False, config=None):
     """
-    Importer for the GEM_GPPT gas powerplant tracker.
+    Importer for the global gas powerplant tracker from global energy monitor.
 
     Parameters
     ----------
@@ -1550,23 +1597,23 @@ def GEM_GGPT(raw=False, update=False, config=None):
         e.g. powerplantmatching.config.get_config(target_countries='Italy'),
         defaults to powerplantmatching.config.get_config()
     """
-    if config is None:
-        config = get_config()
+    config = get_config() if config is None else config
+    fn = get_raw_file("GGPT", update=update, config=config)
+    df = pd.read_excel(fn, sheet_name="Gas plants - data")
 
-        fn = get_raw_file("GEM_GGPT", update=update, config=config)
-        df = pd.read_csv(fn, comment="#")
     if raw:
         return df
 
     RENAME_COLUMNS = {
-        "Country/area": "Country",
-        "name": "Name",
+        "Plant name": "Name",
         "Fuel": "Fueltype",
         "Capacity elec. (MW)": "Capacity",
         "Latitude": "lat",
         "Longitude": "lon",
         "Start year": "DateIn",
         "Retired year": "DateOut",
+        "CHP": "Set",
+        "GEM unit ID": "projectID",
     }
 
     technology_dict = {
@@ -1578,13 +1625,65 @@ def GEM_GGPT(raw=False, update=False, config=None):
         "ST": "Steam Turbine",
     }
 
-    df.rename(columns=RENAME_COLUMNS, inplace=True)
+    set_dict = {
+        "Y": "CHP",
+        "N": "PP",
+        "not found": "PP",
+    }
 
-    # Consistent country names for dataset
-
-    df = convert_to_short_name(df)
-    df.dropna(subset="Capacity", inplace=True)
-
-    df["Fueltype"] = "Natural Gas"
+    df = (
+        df.rename(columns=RENAME_COLUMNS)
+        .pipe(clean_name)
+        .pipe(set_column_name, "GGPT")
+        .pipe(convert_to_short_name)
+        .dropna(subset="Capacity")
+        .assign(Fueltype="Natural Gas")[
+            lambda df: df.Status.isin(["operating", "mothballed", "construction"])
+        ]
+    )
+    df["DateIn"] = pd.to_numeric(df.DateIn, errors="coerce")
+    df["lat"] = pd.to_numeric(df.lat, errors="coerce")
+    df["lon"] = pd.to_numeric(df.lon, errors="coerce")
     df.Technology.replace(technology_dict, inplace=True)
+    df.Set.replace(set_dict, inplace=True)
+    df = df[df.columns.intersection(config.get("target_columns"))]
+    df = df.pipe(config_filter, config)
+
+    return df
+
+
+# deprecated alias for GGPT
+@deprecated(
+    deprecated_in="0.5.5",
+    removed_in="0.6",
+    details="Use `GGPT` instead.",
+)
+def GEM_GGPT(*args, **kwargs):
+    return GGPT(*args, **kwargs)
+
+
+def EXTERNAL_DATABASE(raw=False, update=True, config=None):
+    """
+    Importer for external custom databases.
+    Parameters
+    ----------
+    raw : boolean, default False
+        Whether to return the original dataset
+    update: bool, default True (unused)
+        Whether to update the data from the url.
+    config : dict, default None
+        Add custom specific configuration,
+        e.g. powerplantmatching.config.get_config(target_countries='Italy'),
+        defaults to powerplantmatching.config.get_config()
+    """
+    if config is None:
+        return pd.DataFrame()
+
+    df = pd.read_csv(config["EXTERNAL_DATABASE"]["fn"], low_memory=False)
+
+    if raw:
+        return df
+
+    df = df.pipe(set_column_name, "EXTERNAL_DATABASE").pipe(config_filter, config)
+
     return df
