@@ -63,17 +63,18 @@ def fueltype_stats(df):
 
 def powerplant_map(
     df,
-    scale=1e2,
+    scale=1e1,
+    alpha=0.6,
     european_bounds=True,
     fillcontinents=False,
     legendscale=1,
     resolution=True,
-    **kwargs
+    figsize=None,
+    ncol=2,
+    loc="upper left",
 ):
-
     df = get_obj_if_Acc(df)
     # TODO: add reference circle in legend
-    figsize = kwargs.get("figsize", (11, 9))
     with sns.axes_style("darkgrid"):
         df = set_uncommon_fueltypes_to_other(df)
         shown_fueltypes = df.Fueltype.unique()
@@ -88,6 +89,7 @@ def powerplant_map(
             c=df.Fueltype.map(get_config()["fuel_to_color"]),
             edgecolor="face",
             facecolor="face",
+            alpha=alpha,
         )
 
         legendcols = pd.Series(get_config()["fuel_to_color"]).reindex(shown_fueltypes)
@@ -104,8 +106,8 @@ def powerplant_map(
             legendcols.index,
             handler_map=make_handler_map_to_scale_circles_as_in(ax),
             markerscale=1,
-            ncol=kwargs.get("ncol", 2),
-            loc=kwargs.get("loc", "upper left"),
+            ncol=ncol,
+            loc=loc,
             frameon=True,
             fancybox=True,
             edgecolor="w",
@@ -287,7 +289,7 @@ def boxplot_gross_to_net(axes_style="darkgrid", **kwargs):
         df = gtn(return_entire_data=True).loc[
             lambda df: df.energy_source_level_2 != "Hydro"
         ]
-        df.loc[:, "FuelTech"] = df.energy_source_level_2 + "\n(" + df.technology + ")"
+        df["FuelTech"] = df.energy_source_level_2 + "\n(" + df.technology + ")"
         df = df.groupby("FuelTech").filter(lambda x: len(x) >= 10)
         dfg = df.groupby("FuelTech")
         # plot
@@ -312,7 +314,7 @@ def boxplot_matchcount(df):
     names as the last columns.
     """
     # Mend needed data
-    df.loc[:, "Matches"] = df.projectID.apply(len)
+    df["Matches"] = df.projectID.apply(len)
 
     # Plot
     fig, ax = plt.subplots(figsize=(8, 4.5))
@@ -372,7 +374,6 @@ def draw_basemap(
     fillcontinents=True,
     **kwds
 ):
-
     if cartopy_present:
         if ax is None:
             ax = plt.gca(projection=ccrs.PlateCarree())
